Properties Methods Events Config Options Direct Link

    CalendarView
      DayBodyView

# Class Ext.ensible.cal.DayBodyView

Package: | Ext.ensible.cal
Defined In: | DayBodyView.js
Class: | DayBodyView
Extends: | CalendarView

This is the scrolling container within the day and week views where non-all-day events are displayed. Normally you should not need to use this class directly -- instead you should use DayView which aggregates this class and the DayHeaderView into the single unified view presented by CalendarPanel.

## Config Options

Config Options | Defined By
--- | ---
| calendarStore : Ext.data.Store The store which is bound to this calendar and contains CalendarRecords. This is an optional store that provides mult... The store which is bound to this calendar and contains CalendarRecords. This is an optional store that provides multi-calendar (and multi-color) support. If available an additional field for selecting the calendar in which to save an event will be shown in the edit forms. If this store is not available then all events will simply use the default calendar (and color). | CalendarView
| dateParamEnd : String The param name representing the end date of the current view range that's passed in requests to retrieve events when... The param name representing the end date of the current view range that's passed in requests to retrieve events when loading the view (defauts to 'end'). | CalendarView
| dateParamFormat : String The format to use for date parameters sent with requests to retrieve events for the calendar (defaults to 'Y-m-d', e.... The format to use for date parameters sent with requests to retrieve events for the calendar (defaults to 'Y-m-d', e.g. '2010-10-31') | CalendarView
| dateParamStart : String The param name representing the start date of the current view range that's passed in requests to retrieve events wh... The param name representing the start date of the current view range that's passed in requests to retrieve events when loading the view (defauts to 'start'). | CalendarView
| ddCreateEventText : String The text to display inside the drag proxy while dragging over the calendar to create a new event (defaults to 'Crea... The text to display inside the drag proxy while dragging over the calendar to create a new event (defaults to 'Create event for {0}' where {0} is a date range supplied by the view) | CalendarView
| ddMoveEventText : String The text to display inside the drag proxy while dragging an event to reposition it (defaults to 'Move event to {0}'... The text to display inside the drag proxy while dragging an event to reposition it (defaults to 'Move event to {0}' where {0} is the updated event start date/time supplied by the view) | CalendarView
| ddResizeEventText : String The string displayed to the user in the drag proxy while dragging the resize handle of an event (defaults to 'Updat... The string displayed to the user in the drag proxy while dragging the resize handle of an event (defaults to 'Update event to {0}' where {0} is the updated event start-end range supplied by the view). Note that this text is only used in views that allow resizing of events. | CalendarView
| defaultEventTitleText : String The default text to display as the title of an event that has a null or empty string title value (defaults to '(No ti... The default text to display as the title of an event that has a null or empty string title value (defaults to '(No title)') | CalendarView
| editModal : Boolean True to show the default event editor window modally over the entire page, false to allow user interaction with the p... True to show the default event editor window modally over the entire page, false to allow user interaction with the page while showing the window (the default). Note that if you replace the default editor window with some alternate component this config will no longer apply. | CalendarView
| enableAddFx : Boolean True to enable a visual effect on adding a new event (the default), false to disable it. Note that if enableFx is f... True to enable a visual effect on adding a new event (the default), false to disable it. Note that if enableFx is false it will override this value. The specific effect that runs is defined in the doAddFx method. | CalendarView
| enableContextMenus : Boolean True to enable automatic right-click context menu handling in the calendar views (the default), false to disable the... True to enable automatic right-click context menu handling in the calendar views (the default), false to disable them. Different context menus are provided when clicking on events vs. the view background. | CalendarView
| enableDD : Boolean True to enable drag and drop in the calendar view (the default), false to disable it | CalendarView
| enableEditDetails : Boolean True to show a link on the event edit window to allow switching to the detailed edit form (the default), false to rem... True to show a link on the event edit window to allow switching to the detailed edit form (the default), false to remove the link and disable detailed event editing. | CalendarView
| enableFx : Boolean Determines whether or not visual effects for CRUD actions are enabled (defaults to true). If this is false it will o... Determines whether or not visual effects for CRUD actions are enabled (defaults to true). If this is false it will override any values for enableAddFx, enableUpdateFx or enableRemoveFx and all animations will be disabled. | CalendarView
| enableRemoveFx : Boolean True to enable a visual effect on removing an event (the default), false to disable it. Note that if enableFx is fa... True to enable a visual effect on removing an event (the default), false to disable it. Note that if enableFx is false it will override this value. The specific effect that runs is defined in the doRemoveFx method. | CalendarView
| enableUpdateFx : Boolean True to enable a visual effect on updating an event, false to disable it (the default). Note that if enableFx is fa... True to enable a visual effect on updating an event, false to disable it (the default). Note that if enableFx is false it will override this value. The specific effect that runs is defined in the doUpdateFx method. | CalendarView
| eventStore : Ext.data.Store The store which is bound to this calendar and contains EventRecords. Note that this is an alias to the default store... The store which is bound to this calendar and contains EventRecords. Note that this is an alias to the default store config (to differentiate that from the optional calendarStore config), and either can be used interchangeably. | CalendarView
| monitorResize : Boolean True to monitor the browser's resize event (the default), false to ignore it. If the calendar view is rendered into ... True to monitor the browser's resize event (the default), false to ignore it. If the calendar view is rendered into a fixed-size container this can be set to false. However, if the view can change dimensions (e.g., it's in fit layout in a viewport or some other resizable container) it is very important that this config is true so that any resize event propagates properly to all subcomponents and layouts get recalculated properly. | CalendarView
| nextMonthCls : String A CSS class to apply to any days that fall in the month after the current view's month (defaults to 'ext-cal-day-next... A CSS class to apply to any days that fall in the month after the current view's month (defaults to 'ext-cal-day-next' which highlights next month days in light gray). To disable this styling set the value to null or ''. | CalendarView
| prevMonthCls : String A CSS class to apply to any days that fall in the month previous to the current view's month (defaults to 'ext-cal-da... A CSS class to apply to any days that fall in the month previous to the current view's month (defaults to 'ext-cal-day-prev' which highlights previous month days in light gray). To disable this styling set the value to null or ''. | CalendarView
| readOnly : Boolean True to prevent clicks on events or the view from providing CRUD capabilities, false to enable CRUD (the default). | CalendarView
| spansHavePriority : Boolean Allows switching between two different modes of rendering events that span multiple days. When true, span events are... Allows switching between two different modes of rendering events that span multiple days. When true, span events are always sorted first, possibly at the expense of start dates being out of order (e.g., a span event that starts at 11am one day and spans into the next day would display before a non-spanning event that starts at 10am, even though they would not be in date order). This can lead to more compact layouts when there are many overlapping events. If false (the default), events will always sort by start date first which can result in a less compact, but chronologically consistent layout. | CalendarView
| startDay : Number The 0-based index for the day on which the calendar week begins (0=Sunday, which is the default) | CalendarView
| suppressBrowserContextMenu : Boolean When enableContextMenus is true, the browser context menu will automatically be suppressed whenever a custom context... When enableContextMenus is true, the browser context menu will automatically be suppressed whenever a custom context menu is displayed. When this option is true, right-clicks on elements that do not have a custom context menu will also suppress the default browser context menu (no menu will be shown at all). When false, the browser context menu will still show if the right-clicked element has no custom menu (this is the default). | CalendarView
| todayCls : String A CSS class to apply to the current date when it is visible in the current view (defaults to 'ext-cal-day-today' whic... A CSS class to apply to the current date when it is visible in the current view (defaults to 'ext-cal-day-today' which highlights today in yellow). To disable this styling set the value to null or ''. | CalendarView
| todayText : String The text to display in the current day's box in the calendar when showTodayText is true (defaults to 'Today') | CalendarView
| trackMouseOver : Boolean Whether or not the view tracks and responds to the browser mouseover event on contained elements (defaults to true).... Whether or not the view tracks and responds to the browser mouseover event on contained elements (defaults to true). If you don't need mouseover event highlighting you can disable this. | CalendarView
| weekendCls : String A CSS class to apply to weekend days in the current view (defaults to 'ext-cal-day-we' which highlights weekend days ... A CSS class to apply to weekend days in the current view (defaults to 'ext-cal-day-we' which highlights weekend days in light blue). To disable this styling set the value to null or ''. | CalendarView

## Public Properties

This class has no public properties.

## Public Methods

Method | Defined By
--- | ---
| DayBodyView( `Object config` ) Parameters: `config` : Object The config object Returns: void | DayBodyView
| deleteEvent( `Object rec` ) : void Delete the specified event. Delete the specified event. Parameters: `rec` : Object The event record Returns: void | CalendarView
| disableStoreEvents() : CalendarView Disable store event monitoring within this view. Note that if you do this the view will no longer refresh itself aut... Disable store event monitoring within this view. Note that if you do this the view will no longer refresh itself automatically when CRUD actions occur. To enable store events see enableStoreEvents. Parameters: None. Returns: `CalendarView` this | CalendarView
| dismissEventEditor( [`String dismissMethod`] ) : Ext.ensible.cal.CalendarView Dismiss the currently configured event editor view (by default the shared instance of EventEditWindow, which will b... Dismiss the currently configured event editor view (by default the shared instance of EventEditWindow, which will be hidden). Parameters: `dismissMethod` : String (optional) The method name to call on the editor that will dismiss it (defaults to 'hide' which will be called on the default editor window) Returns: `Ext.ensible.cal.CalendarView` this | CalendarView
| doAddFx( `Ext.CompositeElement el`, `Object options` ) : void Provides the element effect(s) to run after an event is added. The method is passed a Ext.CompositeElement that cont... Provides the element effect(s) to run after an event is added. The method is passed a Ext.CompositeElement that contains one or more elements in the DOM representing the event that was added. The default effect is fadeIn. Note that this method will only be called when enableAddFx is true (it is true by default). Parameters: `el` : Ext.CompositeElement The Ext.CompositeElement representing the added event `options` : Object An options object to be passed through to any Element.Fx methods. By default this object only contains the current scope (`{scope:this}`) but you can also add any additional fx-specific options that might be needed for a particular effect to this object. Returns: void | CalendarView
- | doRemoveFx( `Ext.CompositeElement el`, `Object options` ) : void Provides the element effect(s) to run after an event is removed. The method is passed a Ext.CompositeElement that co... Provides the element effect(s) to run after an event is removed. The method is passed a Ext.CompositeElement that contains one or more elements in the DOM representing the event that was removed. The default effect is fadeOut. Note that this method will only be called when enableRemoveFx is true (it is true by default). Parameters: `el` : Ext.CompositeElement The Ext.CompositeElement representing the removed event `options` : Object An options object to be passed through to any Element.Fx methods. By default this object contains the following properties:
      {
         remove: true, // required by fadeOut to actually remove the element(s)

         scope: this,  // required for the callback

         callback: fn  // required to refresh the view after the fx finish

      }
While you can modify this options object as needed if you change the effect used, please note that the callback method (and scope) MUST still be passed in order for the view to refresh correctly after the removal. Please see the inline code comments before overriding this method. Returns: void | CalendarView
| doUpdateFx( `Ext.CompositeElement el`, `Object options` ) : void Provides the element effect(s) to run after an event is updated. The method is passed a Ext.CompositeElement that co... Provides the element effect(s) to run after an event is updated. The method is passed a Ext.CompositeElement that contains one or more elements in the DOM representing the event that was updated. The default effect is highlight. Note that this method will only be called when enableUpdateFx is true (it is false by default). Parameters: `el` : Ext.CompositeElement The Ext.CompositeElement representing the updated event `options` : Object An options object to be passed through to any Element.Fx methods. By default this object only contains the current scope (`{scope:this}`) but you can also add any additional fx-specific options that might be needed for a particular effect to this object. Returns: void | CalendarView
| enableStoreEvents() : CalendarView Enable store event monitoring within this view if disabled by disbleStoreEvents. Enable store event monitoring within this view if disabled by disbleStoreEvents. Parameters: None. Returns: `CalendarView` this | CalendarView
| getEventAllDayTemplate() : Ext.XTemplate Returns the XTemplate that is bound to the calendar's event store (it expects records of type Ext.ensible.cal.EventRe... Returns the XTemplate that is bound to the calendar's event store (it expects records of type Ext.ensible.cal.EventRecord) to populate the calendar views with all-day events. Internally this method by default generates different markup for browsers that support CSS border radius and those that don't. This method can be overridden as needed to customize the markup generated. Note that this method calls getEventBodyMarkup to retrieve the body markup for events separately from the surrounding container markup. This provdes the flexibility to customize what's in the body without having to override the entire XTemplate. If you do override this method, you should make sure that your overridden version also does the same. Parameters: None. Returns: `Ext.XTemplate` The event XTemplate | DayBodyView
| getEventBodyMarkup() : String Returns a string of HTML template markup to be used as the body portion of the event template created by getEventTem... Returns a string of HTML template markup to be used as the body portion of the event template created by getEventTemplate. This provides the flexibility to customize what's in the body without having to override the entire XTemplate. This string can include any valid Ext.Template code, and any data tokens accessible to the containing event template can be referenced in this string. Parameters: None. Returns: `String` The body template string | CalendarView
| getEventClass( `Ext.ensible.cal.EventRecord rec`, `Boolean isAllDay`, `Object templateData`, `Ext.data.Store store` ) : String This is undefined by default, but can be implemented to allow custom CSS classes and template data to be conditional... This is undefined by default, but can be implemented to allow custom CSS classes and template data to be conditionally applied to events during rendering. This function will be called with the parameter list shown below and is expected to return the CSS class name (or empty string '' for none) that will be added to the event element's wrapping div. To apply multiple class names, simply return them space-delimited within the string (e.g., 'my-class another-class'). Example usage, applied in a CalendarPanel config:
    // This example assumes a custom field of 'IsHoliday' has been added to EventRecord

    viewConfig: {
        getEventClass: function(rec, allday, templateData, store){
            if(rec.data.IsHoliday){
                templateData.iconCls = 'holiday';
                return 'evt-holiday';
            }
            templateData.iconCls = 'plain';
            return '';
        },
        getEventBodyMarkup : function(){
            // This is simplified, but shows the symtax for how you could add a

            // custom placeholder that maps back to the templateData property created

            // in getEventClass. Note that this is standard Ext template syntax.

            if(!this.eventBodyMarkup){
                this.eventBodyMarkup = '<span class="{iconCls}"></span> {Title}';
            }
            return this.eventBodyMarkup;
        }
    }
Parameters: `rec` : Ext.ensible.cal.EventRecord The record being rendered `isAllDay` : Boolean A flag indicating whether the event will be rendered as an all-day event. Note that this will not necessarily correspond with the value of the `EventRecord.IsAllDay` field — events that span multiple days will be rendered using the all-day event template regardless of the field value. If your logic for this function needs to know whether or not the event will be rendered as an all-day event, this value should be used. `templateData` : Object A plain JavaScript object that is empty by default. You can add custom properties to this object that will then be passed into the event template for the specific event being rendered. If you have overridden the default event template and added custom data placeholders, you can use this object to pass the data into the template that will replace those placeholders. `store` : Ext.data.Store The Event data store in use by the view Returns: `String` A space-delimited CSS class string (or '') | CalendarView
| getEventEls( `String eventId` ) : Ext.CompositeElement Parameters: `eventId` : String Returns: `Ext.CompositeElement` The matching CompositeElement of nodes that comprise the rendered event. Any event that spans across a view boundary will contain more than one internal Element. | CalendarView
| getEventIdFromEl( `String/Element/HTMLElement el` ) : void Retrieve an Event object's id from its corresponding node in the DOM. Retrieve an Event object's id from its corresponding node in the DOM. Parameters: `el` : String/Element/HTMLElement An Ext.Element, DOM node or id Returns: void | CalendarView
| getEventSelectorCls( `String eventId`, `Boolean forSelect` ) : String Parameters: `eventId` : String `forSelect` : Boolean Returns: `String` The selector class | CalendarView
| getEventTemplate() : Ext.XTemplate Returns the XTemplate that is bound to the calendar's event store (it expects records of type Ext.ensible.cal.EventR... Returns the XTemplate that is bound to the calendar's event store (it expects records of type Ext.ensible.cal.EventRecord) to populate the calendar views with events. Internally this method by default generates different markup for browsers that support CSS border radius and those that don't. This method can be overridden as needed to customize the markup generated. Note that this method calls getEventBodyMarkup to retrieve the body markup for events separately from the surrounding container markup. This provides the flexibility to customize what's in the body without having to override the entire XTemplate. If you do override this method, you should make sure that your overridden version also does the same. Parameters: None. Returns: `Ext.XTemplate` The event XTemplate | CalendarView
| getStartDate() : Date Returns the start date of the view, as set by setStartDate. Note that this may not be the first date displayed in t... Returns the start date of the view, as set by setStartDate. Note that this may not be the first date displayed in the rendered calendar -- to get the start and end dates displayed to the user use getViewBounds. Parameters: None. Returns: `Date` The start date | CalendarView
| getStoreDateParams() : Object Returns an object containing the start and end dates to be passed as params in all calls to load the event store. Th... Returns an object containing the start and end dates to be passed as params in all calls to load the event store. The param names are customizable using dateParamStart and dateParamEnd and the date format used in requests is defined by dateParamFormat. If you need to add additional parameters to be sent when loading the store see getStoreParams. Parameters: None. Returns: `Object` An object containing the start and end dates | CalendarView
| getStoreParams() : Object Returns an object containing all key/value params to be passed when loading the event store. By default the returned... Returns an object containing all key/value params to be passed when loading the event store. By default the returned object will simply be the same object returned by getStoreDateParams, but this method is intended to be overridden if you need to pass anything in addition to start and end dates. See the inline code comments when overriding for details. Parameters: None. Returns: `Object` An object containing all params to be sent when loading the event store | CalendarView
| getViewBounds() : Object Returns the start and end boundary dates currently displayed in the view. The method returns an object literal that ... Returns the start and end boundary dates currently displayed in the view. The method returns an object literal that contains the following properties: start Date : The start date of the view end Date : The end date of the view For example:
    var bounds = view.getViewBounds();
    alert('Start: '+bounds.start);
    alert('End: '+bounds.end);
Parameters: None. Returns: `Object` An object literal containing the start and end values | CalendarView
| highlightEvent( `Ext.CompositeElement els`, [`Object color`], [`Object o`] ) : void Visually highlights an event using Ext.Fx.highlight config options. Visually highlights an event using Ext.Fx.highlight config options. Parameters: `els` : Ext.CompositeElement The element(s) to highlight `color` : Object (optional) The highlight color. Should be a 6 char hex color without the leading # (defaults to yellow: 'ffff9c') `o` : Object (optional) Object literal with any of the Ext.Fx config options. See Ext.Fx.highlight for usage examples. Returns: void | CalendarView
| isToday() : Boolean Returns true if the view is currently displaying today's date, else false. Returns true if the view is currently displaying today's date, else false. Parameters: None. Returns: `Boolean` True or false | CalendarView
| moveDays( `Number value` ) : Date Shifts the view by the passed number of days relative to the currently set date Shifts the view by the passed number of days relative to the currently set date Parameters: `value` : Number The number of days (positive or negative) by which to shift the view Returns: `Date` The new date | CalendarView
| moveEvent( `Object rec`, `Object dt` ) : void Move the event to a new start date, preserving the original event duration. Move the event to a new start date, preserving the original event duration. Parameters: `rec` : Object The event record `dt` : Object The new start date Returns: void | CalendarView
| moveMonths( `Number value` ) : Date Shifts the view by the passed number of months relative to the currently set date Shifts the view by the passed number of months relative to the currently set date Parameters: `value` : Number The number of months (positive or negative) by which to shift the view Returns: `Date` The new date | CalendarView
| moveNext() : Date Updates the view to the next consecutive date(s) Updates the view to the next consecutive date(s) Parameters: None. Returns: `Date` The new date | CalendarView
| movePrev() : Date Updates the view to the previous consecutive date(s) Updates the view to the previous consecutive date(s) Parameters: None. Returns: `Date` The new date | CalendarView
| moveTo( `Date dt` ) : void Updates the view to contain the passed date Updates the view to contain the passed date Parameters: `dt` : Date The date to display Returns: void | CalendarView
| moveToday() : Date Updates the view to show today Updates the view to show today Parameters: None. Returns: `Date` Today's date | CalendarView
| moveWeeks( `Number value` ) : Date Shifts the view by the passed number of weeks relative to the currently set date Shifts the view by the passed number of weeks relative to the currently set date Parameters: `value` : Number The number of weeks (positive or negative) by which to shift the view Returns: `Date` The new date | CalendarView
| refresh( `Boolean reloadData` ) : void Refresh the current view, optionally reloading the event store also. While this is normally managed internally on an... Refresh the current view, optionally reloading the event store also. While this is normally managed internally on any navigation and/or CRUD action, there are times when you might want to refresh the view manually (e.g., if you'd like to reload using different params). Parameters: `reloadData` : Boolean True to reload the store data first, false to simply redraw the view using current data (defaults to false) Returns: void | CalendarView
| reloadStore( [`Object options`] ) : void Reloads the view's underlying event store using the params returned from getStoreParams. Reloading the store is typi... Reloads the view's underlying event store using the params returned from getStoreParams. Reloading the store is typically managed automatically by the view itself, but the method is available in case a manual reload is ever needed. Parameters: `options` : Object (optional) An object matching the format used by Store's load method Returns: void | CalendarView
| scrollTo( `Number y`, [`Boolean defer`] ) : void Scrolls the container to the specified vertical position. If the view is large enough that there is no scroll overflo... Scrolls the container to the specified vertical position. If the view is large enough that there is no scroll overflow then this method will have no affect. Parameters: `y` : Number The new vertical scroll position in pixels `defer` : Boolean (optional) True to slightly defer the call, false to execute immediately. This method will automatically defer itself for IE and Opera (even if you pass false) otherwise the scroll position will not update in those browsers. You can optionally pass true, however, to force the defer in all browsers, or use your own custom conditions to determine whether this is needed. Note that this method should not generally need to be called directly as scroll position is managed internally. Returns: void | DayBodyView
| setCalendarStore( `Ext.data.Store store` ) : void Sets the calendar store used by the calendar (contains records of type CalendarRecord). Sets the calendar store used by the calendar (contains records of type CalendarRecord). Parameters: `store` : Ext.data.Store Returns: void | CalendarView
| setStartDate( `Date dt` ) : void Sets the start date used to calculate the view boundaries to display. The displayed view will be the earliest and l... Sets the start date used to calculate the view boundaries to display. The displayed view will be the earliest and latest dates that match the view requirements and contain the date passed to this function. Parameters: `dt` : Date The date used to calculate the new view boundaries Returns: void | CalendarView
| setStore( `Ext.data.Store store` ) : void Sets the event store used by the calendar to display events. Sets the event store used by the calendar to display events. Parameters: `store` : Ext.data.Store Returns: void | CalendarView
| showEventEditor( `Ext.ensible.cal.EventRecord rec`, `Ext.Element/HTMLNode animateTarget` ) : Ext.ensible.cal.CalendarView Show the currently configured event editor view (by default the shared instance of EventEditWindow). Show the currently configured event editor view (by default the shared instance of EventEditWindow). Parameters: `rec` : Ext.ensible.cal.EventRecord The event record `animateTarget` : Ext.Element/HTMLNode The reference element that is being edited. By default this is used as the target for animating the editor window opening and closing. If this method is being overridden to supply a custom editor this parameter can be ignored if it does not apply. Returns: `Ext.ensible.cal.CalendarView` this | CalendarView

## Public Events

Event | Defined By
--- | ---
| beforedatechange : ( `Ext.ensible.cal.CalendarView this`, `Date startDate`, `Date newStartDate`, `Date viewStart`, `Date viewEnd` ) Fires before the start date of the view changes, giving you an opportunity to save state or anything else you may nee... Fires before the start date of the view changes, giving you an opportunity to save state or anything else you may need to do prior to the UI view changing. This is a cancelable event, so returning false from a handler will cancel both the view change and the setting of the start date. Listeners will be called with the following arguments: `this` : Ext.ensible.cal.CalendarView `startDate` : Date The current start date of the view (as explained in getStartDate `newStartDate` : Date The new start date that will be set when the view changes `viewStart` : Date The first displayed date in the current view `viewEnd` : Date The last displayed date in the current view | CalendarView
| beforeeventdelete : ( `Ext.ensible.cal.CalendarView this`, `Ext.ensible.cal.EventRecord rec`, `Ext.Element el` ) Fires before an event is deleted by the user. This is a cancelable event, so returning false from a handler will ca... Fires before an event is deleted by the user. This is a cancelable event, so returning false from a handler will cancel the delete operation. Listeners will be called with the following arguments: `this` : Ext.ensible.cal.CalendarView `rec` : Ext.ensible.cal.EventRecord The record for the event that was deleted `el` : Ext.Element The target element | CalendarView
| beforeeventmove : ( `Ext.ensible.cal.CalendarView this`, `Ext.ensible.cal.EventRecord rec`, `Date dt` ) Fires before an event element is dragged by the user and dropped in a new position. This is a cancelable event, so ... Fires before an event element is dragged by the user and dropped in a new position. This is a cancelable event, so returning false from a handler will cancel the move operation. This could be useful for validating that a user can only move events within a certain date range. Listeners will be called with the following arguments: `this` : Ext.ensible.cal.CalendarView `rec` : Ext.ensible.cal.EventRecord The record for the event that will be moved `dt` : Date The new start date to be set (the end date will be automaticaly adjusted to match the event duration) | CalendarView
| beforeeventresize : ( `Ext.ensible.cal.DayBodyView this`, `Ext.ensible.cal.EventRecord rec`, `Object data` ) Fires after the user drags the resize handle of an event to resize it, but before the resize operation is carried out... Fires after the user drags the resize handle of an event to resize it, but before the resize operation is carried out. This is a cancelable event, so returning false from a handler will cancel the resize operation. Listeners will be called with the following arguments: `this` : Ext.ensible.cal.DayBodyView `rec` : Ext.ensible.cal.EventRecord The original record for the event that was resized `data` : Object An object containing the new start and end dates that will be set into the event record if the event is not canceled. Format of the object is: {StartDate: [date], EndDate: [date]} | DayBodyView
| datechange : ( `Ext.ensible.cal.CalendarView this`, `Date startDate`, `Date viewStart`, `Date viewEnd` ) Fires after the start date of the view has changed. If you need to cancel the date change you should handle the bef... Fires after the start date of the view has changed. If you need to cancel the date change you should handle the beforedatechange event and return false from your handler function. Listeners will be called with the following arguments: `this` : Ext.ensible.cal.CalendarView `startDate` : Date The start date of the view (as explained in getStartDate `viewStart` : Date The first displayed date in the view `viewEnd` : Date The last displayed date in the view | CalendarView
| dayclick : ( `Ext.ensible.cal.DayBodyView this`, `Date dt`, `Boolean allday`, `Ext.Element el` ) Fires after the user clicks within the view container and not on an event element. This is a cancelable event, so re... Fires after the user clicks within the view container and not on an event element. This is a cancelable event, so returning false from a handler will cancel the click without displaying the event editor view. This could be useful for validating that a user can only create events on certain days. Listeners will be called with the following arguments: `this` : Ext.ensible.cal.DayBodyView `dt` : Date The date/time that was clicked on `allday` : Boolean True if the day clicked on represents an all-day box, else false. Clicks within the DayBodyView always return false for this param. `el` : Ext.Element The Element that was clicked on | DayBodyView
| dayout : ( `Ext.ensible.cal.CalendarView this`, `Date dt`, `Ext.Element el` ) Fires when the mouse exits a day element Fires when the mouse exits a day element Listeners will be called with the following arguments: `this` : Ext.ensible.cal.CalendarView `dt` : Date The date that is exited `el` : Ext.Element The day Element that is exited | CalendarView
| dayover : ( `Ext.ensible.cal.CalendarView this`, `Date dt`, `Ext.Element el` ) Fires while the mouse is over a day element Fires while the mouse is over a day element Listeners will be called with the following arguments: `this` : Ext.ensible.cal.CalendarView `dt` : Date The date that is being moused over `el` : Ext.Element The day Element that is being moused over | CalendarView
| editdetails : ( `Ext.ensible.cal.CalendarView this`, `Ext.ensible.cal.EventRecord rec`, `Ext.Element el` ) Fires when the user selects the option in this window to continue editing in the detailed edit form (by default, an ... Fires when the user selects the option in this window to continue editing in the detailed edit form (by default, an instance of Ext.ensible.cal.EventEditForm. Handling code should hide this window and transfer the current event record to the appropriate instance of the detailed form by showing it and calling loadRecord. Listeners will be called with the following arguments: `this` : Ext.ensible.cal.CalendarView `rec` : Ext.ensible.cal.EventRecord The record that is currently being edited `el` : Ext.Element The target element | CalendarView
| eventadd : ( `Ext.ensible.cal.CalendarView this`, `Ext.ensible.cal.EventRecord rec` ) Fires after a new event has been added to the underlying store Fires after a new event has been added to the underlying store Listeners will be called with the following arguments: `this` : Ext.ensible.cal.CalendarView `rec` : Ext.ensible.cal.EventRecord The new record that was added | CalendarView
| eventcancel : ( `Ext.ensible.cal.CalendarView this`, `Ext.ensible.cal.EventRecord rec` ) Fires after an event add/edit operation has been canceled by the user and no store update took place Fires after an event add/edit operation has been canceled by the user and no store update took place Listeners will be called with the following arguments: `this` : Ext.ensible.cal.CalendarView `rec` : Ext.ensible.cal.EventRecord The new record that was canceled | CalendarView
| eventclick : ( `Ext.ensible.cal.CalendarView this`, `Ext.ensible.cal.EventRecord rec`, `HTMLNode el` ) Fires after the user clicks on an event element. This is a cancelable event, so returning false from a handler will... Fires after the user clicks on an event element. This is a cancelable event, so returning false from a handler will cancel the click without displaying the event editor view. This could be useful for validating the rules by which events should be editable by the user. Listeners will be called with the following arguments: `this` : Ext.ensible.cal.CalendarView `rec` : Ext.ensible.cal.EventRecord The record for the event that was clicked on `el` : HTMLNode The DOM node that was clicked on | CalendarView
| eventdelete : ( `Ext.ensible.cal.CalendarView this`, `Ext.ensible.cal.EventRecord rec`, `Ext.Element el` ) Fires after an event has been deleted by the user. If you need to cancel the delete operation you should handle the ... Fires after an event has been deleted by the user. If you need to cancel the delete operation you should handle the beforeeventdelete event and return false from your handler function. Listeners will be called with the following arguments: `this` : Ext.ensible.cal.CalendarView `rec` : Ext.ensible.cal.EventRecord The record for the event that was deleted `el` : Ext.Element The target element | CalendarView
| eventmove : ( `Ext.ensible.cal.CalendarView this`, `Ext.ensible.cal.EventRecord rec` ) Fires after an event element has been dragged by the user and dropped in a new position. If you need to cancel the ... Fires after an event element has been dragged by the user and dropped in a new position. If you need to cancel the move operation you should handle the beforeeventmove event and return false from your handler function. Listeners will be called with the following arguments: `this` : Ext.ensible.cal.CalendarView `rec` : Ext.ensible.cal.EventRecord The record for the event that was moved with updated start and end dates | CalendarView
| eventout : ( `Ext.ensible.cal.CalendarView this`, `Ext.ensible.cal.EventRecord rec`, `HTMLNode el` ) Fires anytime the mouse exits an event element Fires anytime the mouse exits an event element Listeners will be called with the following arguments: `this` : Ext.ensible.cal.CalendarView `rec` : Ext.ensible.cal.EventRecord The record for the event that the cursor exited `el` : HTMLNode The DOM node that was exited | CalendarView
| eventover : ( `Ext.ensible.cal.CalendarView this`, `Ext.ensible.cal.EventRecord rec`, `HTMLNode el` ) Fires anytime the mouse is over an event element Fires anytime the mouse is over an event element Listeners will be called with the following arguments: `this` : Ext.ensible.cal.CalendarView `rec` : Ext.ensible.cal.EventRecord The record for the event that the cursor is over `el` : HTMLNode The DOM node that is being moused over | CalendarView
| eventresize : ( `Ext.ensible.cal.DayBodyView this`, `Ext.ensible.cal.EventRecord rec` ) Fires after the user has drag-dropped the resize handle of an event and the resize operation is complete. If you need... Fires after the user has drag-dropped the resize handle of an event and the resize operation is complete. If you need to cancel the resize operation you should handle the beforeeventresize event and return false from your handler function. Listeners will be called with the following arguments: `this` : Ext.ensible.cal.DayBodyView `rec` : Ext.ensible.cal.EventRecord The record for the event that was resized containing the updated start and end dates | DayBodyView
| eventsrendered : ( `Ext.ensible.cal.CalendarView this` ) Fires after events are finished rendering in the view Fires after events are finished rendering in the view Listeners will be called with the following arguments: `this` : Ext.ensible.cal.CalendarView | CalendarView
| eventupdate : ( `Ext.ensible.cal.CalendarView this`, `Ext.ensible.cal.EventRecord rec` ) Fires after an existing event has been updated Fires after an existing event has been updated Listeners will be called with the following arguments: `this` : Ext.ensible.cal.CalendarView `rec` : Ext.ensible.cal.EventRecord The new record that was updated | CalendarView
| initdrag : ( `Ext.ensible.cal.CalendarView this` ) Fires when a drag operation is initiated in the view Fires when a drag operation is initiated in the view Listeners will be called with the following arguments: `this` : Ext.ensible.cal.CalendarView | CalendarView
| rangeselect : ( `Ext.ensible.cal.CalendarView this`, `Object dates`, `Function callback` ) Fires after the user drags on the calendar to select a range of dates/times in which to create an event. This is a ... Fires after the user drags on the calendar to select a range of dates/times in which to create an event. This is a cancelable event, so returning false from a handler will cancel the drag operation and clean up any drag shim elements without displaying the event editor view. This could be useful for validating that a user can only create events within a certain range. Listeners will be called with the following arguments: `this` : Ext.ensible.cal.CalendarView `dates` : Object An object containing the start (StartDate property) and end (EndDate property) dates selected `callback` : Function A callback function that MUST be called after the event handling is complete so that the view is properly cleaned up (shim elements are persisted in the view while the user is prompted to handle the range selection). The callback is already created in the proper scope, so it simply needs to be executed as a standard function call (e.g., callback()). | CalendarView